###################################################
### chunk number 1: preliminaries
###################################################
#line 73 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
options(width = 70, prompt = "R> ", continue = "+  ")
library("Formula")


###################################################
### chunk number 2: example-data
###################################################
#line 167 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
set.seed(1090)
dat <- as.data.frame(matrix(round(runif(21), digits = 2), ncol = 7))
colnames(dat) <- c("y1", "y2", "y3", "x1", "x2", "x3", "x4")
for(i in c(2, 6:7)) dat[[i]] <- factor(dat[[i]] < 0.5,
  labels = c("a", "b"))
dat$y2[1] <- NA
dat


###################################################
### chunk number 3: multi-part1
###################################################
#line 186 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
F1 <- Formula(log(y1) ~ x1 + x2 | I(x1^2))
length(F1)


###################################################
### chunk number 4: multi-part2
###################################################
#line 196 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
mf1 <- model.frame(F1, data = dat)
mf1


###################################################
### chunk number 5: multi-part3
###################################################
#line 204 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
model.response(mf1)


###################################################
### chunk number 6: multi-part4
###################################################
#line 212 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
model.matrix(F1, data = mf1, rhs = 1)
model.matrix(F1, data = mf1, rhs = 2)


###################################################
### chunk number 7: multi-response1
###################################################
#line 228 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
F2 <- Formula(y1 + y2 ~ x3)
length(F2)


###################################################
### chunk number 8: multi-response2
###################################################
#line 235 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
mf2 <- model.frame(F2, data = dat)
mf2


###################################################
### chunk number 9: multi-response3
###################################################
#line 246 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
model.response(mf2)


###################################################
### chunk number 10: multi-response4
###################################################
#line 258 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
model.part(F2, data = mf2, lhs = 1)


###################################################
### chunk number 11: single-response
###################################################
#line 264 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
model.part(F1, data = mf1, lhs = 1, drop = TRUE)


###################################################
### chunk number 12: details1
###################################################
#line 316 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
F3 <- Formula(y1 + y2 | log(y3) ~ x1 + I(x2^2) | 0 + log(x1) | x3 / x4)
F3
length(F3)


###################################################
### chunk number 13: details2
###################################################
#line 330 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
attr(F3, "lhs")


###################################################
### chunk number 14: formula-method
###################################################
#line 367 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
formula(F3)
formula(F3, lhs = 2, rhs = -2)
formula(F3, lhs = c(TRUE, FALSE), rhs = 0)


###################################################
### chunk number 15: terms-method1
###################################################
#line 381 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
terms(F3)


###################################################
### chunk number 16: terms-method
###################################################
#line 387 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
formula(terms(F3))
formula(terms(F3, lhs = 2, rhs = -2))
formula(terms(F3, lhs = c(TRUE, FALSE), rhs = 0))


###################################################
### chunk number 17: model.frame-method
###################################################
#line 401 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
mf3 <- model.frame(F3, data = dat, subset = y1 < 0.75, weights = x1)
mf3


###################################################
### chunk number 18: model.matrix-method
###################################################
#line 410 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
model.matrix(F3, data = mf3, rhs = 2)


###################################################
### chunk number 19: model.response-substitute
###################################################
#line 424 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
model.part(F3, data = mf3, lhs = 1)
model.part(F3, data = mf3, lhs = 2)


###################################################
### chunk number 20: model.foo-methods
###################################################
#line 434 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
model.weights(mf3)


###################################################
### chunk number 21: update-method
###################################################
#line 446 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
update(F1, . ~ . - x1 | . + x1)
update(F1, . + y2 | y3 ~ .)


###################################################
### chunk number 22: as.Formula-method
###################################################
#line 454 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
as.Formula(y1 ~ x1, y2 ~ x2, ~ x3)


###################################################
### chunk number 23: ivcoef
###################################################
#line 482 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
ivcoef <- function(formula, data, subset, na.action, ...)
{
  mf <- match.call(expand.dots = FALSE)
  m <- match(c("formula", "data", "subset", "na.action"), names(mf), 0)
  mf <- mf[c(1, m)]
  
  f <- Formula(formula)
  mf[[1]] <- as.name("model.frame")
  mf$formula <- f
  mf <- eval(mf, parent.frame())
  
  y <- model.response(mf)
  x <- model.matrix(f, data = mf, rhs = 1)
  z <- model.matrix(f, data = mf, rhs = 2)

  xz <- as.matrix(lm.fit(z, x)$fitted.values)
  lm.fit(xz, y)$coefficients
}


###################################################
### chunk number 24: ivcoef-example
###################################################
#line 506 "d:/Rcompile/CRANpkg/local/2.12/Formula/inst/doc/Formula.Rnw"
ivcoef(log(y1) ~ x1 | x2, data = dat)


